@@ -3,13 +3,12 @@
 #include "llvm-c/ExecutionEngine.h"
 #include "llvm-c/Object.h"
 
-
-#include "llvm/IR/Module.h"
-#include "llvm/Object/ObjectFile.h"
-#include "llvm/Object/Binary.h"
 #include "llvm/ExecutionEngine/ExecutionEngine.h"
 #include "llvm/ExecutionEngine/JITEventListener.h"
 #include "llvm/ExecutionEngine/ObjectCache.h"
+#include "llvm/IR/Module.h"
+#include "llvm/Object/Binary.h"
+#include "llvm/Object/ObjectFile.h"
 #include "llvm/Support/Memory.h"
 
 #include <cstdio>
@@ -17,68 +16,56 @@
 
 namespace llvm {
 
-    // wrap/unwrap for LLVMTargetMachineRef.
-    // Ripped from lib/Target/TargetMachineC.cpp.
+// wrap/unwrap for LLVMTargetMachineRef.
+// Ripped from lib/Target/TargetMachineC.cpp.
 
-    inline TargetMachine *unwrap(LLVMTargetMachineRef P) {
-        return reinterpret_cast<TargetMachine*>(P);
-    }
-    inline LLVMTargetMachineRef wrap(const TargetMachine *P) {
-    return
-        reinterpret_cast<LLVMTargetMachineRef>(const_cast<TargetMachine*>(P));
-    }
+inline TargetMachine *unwrap(LLVMTargetMachineRef P) {
+    return reinterpret_cast<TargetMachine *>(P);
+}
+inline LLVMTargetMachineRef wrap(const TargetMachine *P) {
+    return reinterpret_cast<LLVMTargetMachineRef>(
+        const_cast<TargetMachine *>(P));
+}
 
-    // unwrap for LLVMObjectFileRef
-    // from Object/Object.cpp
-    namespace object {
+// unwrap for LLVMObjectFileRef
+// from Object/Object.cpp
+namespace object {
 
-        inline OwningBinary<ObjectFile> *unwrap(LLVMObjectFileRef OF) {
-            return reinterpret_cast<OwningBinary<ObjectFile> *>(OF);
-        }
-    } // object
-} // llvm
+inline OwningBinary<ObjectFile> *unwrap(LLVMObjectFileRef OF) {
+    return reinterpret_cast<OwningBinary<ObjectFile> *>(OF);
+}
+} // namespace object
+} // namespace llvm
 
 extern "C" {
 
 API_EXPORT(void)
-LLVMPY_LinkInMCJIT() {
-    LLVMLinkInMCJIT();
-}
+LLVMPY_LinkInMCJIT() { LLVMLinkInMCJIT(); }
 
 API_EXPORT(void)
-LLVMPY_DisposeExecutionEngine(LLVMExecutionEngineRef EE)
-{
+LLVMPY_DisposeExecutionEngine(LLVMExecutionEngineRef EE) {
     LLVMDisposeExecutionEngine(EE);
 }
 
 API_EXPORT(void)
-LLVMPY_AddModule(LLVMExecutionEngineRef EE,
-                 LLVMModuleRef M)
-{
+LLVMPY_AddModule(LLVMExecutionEngineRef EE, LLVMModuleRef M) {
     LLVMAddModule(EE, M);
 }
 
 API_EXPORT(int)
-LLVMPY_RemoveModule(LLVMExecutionEngineRef EE,
-                    LLVMModuleRef M,
-                    char** OutError)
-{
-   return LLVMRemoveModule(EE, M, &M, OutError);
+LLVMPY_RemoveModule(LLVMExecutionEngineRef EE, LLVMModuleRef M,
+                    char **OutError) {
+    return LLVMRemoveModule(EE, M, &M, OutError);
 }
 
 API_EXPORT(void)
-LLVMPY_FinalizeObject(LLVMExecutionEngineRef EE)
-{
+LLVMPY_FinalizeObject(LLVMExecutionEngineRef EE) {
     llvm::unwrap(EE)->finalizeObject();
 }
 
-static
-LLVMExecutionEngineRef
-create_execution_engine(LLVMModuleRef M,
-                        LLVMTargetMachineRef TM,
-                        const char **OutError
-                        )
-{
+static LLVMExecutionEngineRef create_execution_engine(LLVMModuleRef M,
+                                                      LLVMTargetMachineRef TM,
+                                                      const char **OutError) {
     LLVMExecutionEngineRef ee = nullptr;
 
     llvm::EngineBuilder eb(std::unique_ptr<llvm::Module>(llvm::unwrap(M)));
@@ -89,7 +76,6 @@ create_execution_engine(LLVMModuleRef M,
     /* EngineBuilder::create loads the current process symbols */
     llvm::ExecutionEngine *engine = eb.create(llvm::unwrap(TM));
 
-
     if (!engine)
         *OutError = LLVMPY_CreateString(err.c_str());
     else
@@ -98,73 +84,57 @@ create_execution_engine(LLVMModuleRef M,
 }
 
 API_EXPORT(LLVMExecutionEngineRef)
-LLVMPY_CreateMCJITCompiler(LLVMModuleRef M,
-                           LLVMTargetMachineRef TM,
-                           const char **OutError)
-{
+LLVMPY_CreateMCJITCompiler(LLVMModuleRef M, LLVMTargetMachineRef TM,
+                           const char **OutError) {
     return create_execution_engine(M, TM, OutError);
 }
 
-
 API_EXPORT(uint64_t)
-LLVMPY_GetGlobalValueAddress(LLVMExecutionEngineRef EE,
-                             const char *Name)
-{
+LLVMPY_GetGlobalValueAddress(LLVMExecutionEngineRef EE, const char *Name) {
     return LLVMGetGlobalValueAddress(EE, Name);
 }
 
 API_EXPORT(uint64_t)
-LLVMPY_GetFunctionAddress(LLVMExecutionEngineRef EE,
-                          const char *Name)
-{
+LLVMPY_GetFunctionAddress(LLVMExecutionEngineRef EE, const char *Name) {
     return LLVMGetFunctionAddress(EE, Name);
 }
 
 API_EXPORT(void)
-LLVMPY_RunStaticConstructors(LLVMExecutionEngineRef EE)
-{
+LLVMPY_RunStaticConstructors(LLVMExecutionEngineRef EE) {
     return LLVMRunStaticConstructors(EE);
 }
 
 API_EXPORT(void)
-LLVMPY_RunStaticDestructors(LLVMExecutionEngineRef EE)
-{
+LLVMPY_RunStaticDestructors(LLVMExecutionEngineRef EE) {
     return LLVMRunStaticDestructors(EE);
 }
 
 API_EXPORT(void)
-LLVMPY_AddGlobalMapping(LLVMExecutionEngineRef EE,
-                        LLVMValueRef Global,
-                        void *Addr)
-{
+LLVMPY_AddGlobalMapping(LLVMExecutionEngineRef EE, LLVMValueRef Global,
+                        void *Addr) {
     LLVMAddGlobalMapping(EE, Global, Addr);
 }
 
 API_EXPORT(LLVMTargetDataRef)
-LLVMPY_GetExecutionEngineTargetData(LLVMExecutionEngineRef EE)
-{
+LLVMPY_GetExecutionEngineTargetData(LLVMExecutionEngineRef EE) {
     return LLVMGetExecutionEngineTargetData(EE);
 }
 
 API_EXPORT(int)
-LLVMPY_TryAllocateExecutableMemory(void)
-{
+LLVMPY_TryAllocateExecutableMemory(void) {
     using namespace llvm::sys;
     std::error_code ec;
-    MemoryBlock mb = Memory::allocateMappedMemory(4096, nullptr,
-                                                  Memory::MF_READ |
-                                                  Memory::MF_WRITE,
-                                                  ec);
+    MemoryBlock mb = Memory::allocateMappedMemory(
+        4096, nullptr, Memory::MF_READ | Memory::MF_WRITE, ec);
     if (!ec) {
         ec = Memory::protectMappedMemory(mb, Memory::MF_READ | Memory::MF_EXEC);
-        (void) Memory::releaseMappedMemory(mb);  /* Should always succeed */
+        (void)Memory::releaseMappedMemory(mb); /* Should always succeed */
     }
     return ec.value();
 }
 
 API_EXPORT(bool)
-LLVMPY_EnableJITEvents(LLVMExecutionEngineRef EE)
-{
+LLVMPY_EnableJITEvents(LLVMExecutionEngineRef EE) {
     llvm::JITEventListener *listener;
     bool result = false;
 
@@ -193,10 +163,10 @@ LLVMPY_MCJITAddObjectFile(LLVMExecutionEngineRef EE, LLVMObjectFileRef ObjF) {
     auto object_file = unwrap(ObjF);
     auto binary_tuple = object_file->takeBinary();
 
-    engine->addObjectFile({std::move(binary_tuple.first), std::move(binary_tuple.second)});
+    engine->addObjectFile(
+        {std::move(binary_tuple.first), std::move(binary_tuple.second)});
 }
 
-
 //
 // Object cache
 //
@@ -210,24 +180,18 @@ typedef struct {
 typedef void (*ObjectCacheNotifyFunc)(void *, const ObjectCacheData *);
 typedef void (*ObjectCacheGetObjectFunc)(void *, ObjectCacheData *);
 
-
 class LLVMPYObjectCache : public llvm::ObjectCache {
-public:
+  public:
     LLVMPYObjectCache(ObjectCacheNotifyFunc notify_func,
-                      ObjectCacheGetObjectFunc getobject_func,
-                      void *user_data)
-    : notify_func(notify_func), getobject_func(getobject_func),
-      user_data(user_data)
-    {
-    }
+                      ObjectCacheGetObjectFunc getobject_func, void *user_data)
+        : notify_func(notify_func), getobject_func(getobject_func),
+          user_data(user_data) {}
 
     virtual void notifyObjectCompiled(const llvm::Module *M,
-                                      llvm::MemoryBufferRef MBR)
-    {
+                                      llvm::MemoryBufferRef MBR) {
         if (notify_func) {
-            ObjectCacheData data = { llvm::wrap(M),
-                                     MBR.getBufferStart(),
-                                     MBR.getBufferSize() };
+            ObjectCacheData data = {llvm::wrap(M), MBR.getBufferStart(),
+                                    MBR.getBufferSize()};
             notify_func(user_data, &data);
         }
     }
@@ -235,12 +199,12 @@ public:
     // MCJIT will call this function before compiling any module
     // MCJIT takes ownership of both the MemoryBuffer object and the memory
     // to which it refers.
-    virtual std::unique_ptr<llvm::MemoryBuffer> getObject(const llvm::Module* M)
-    {
+    virtual std::unique_ptr<llvm::MemoryBuffer>
+    getObject(const llvm::Module *M) {
         std::unique_ptr<llvm::MemoryBuffer> res = nullptr;
 
         if (getobject_func) {
-            ObjectCacheData data = { llvm::wrap(M), nullptr, 0 };
+            ObjectCacheData data = {llvm::wrap(M), nullptr, 0};
 
             getobject_func(user_data, &data);
             if (data.buf_ptr && data.buf_len > 0) {
@@ -254,7 +218,7 @@ public:
         return res;
     }
 
-private:
+  private:
     ObjectCacheNotifyFunc notify_func;
     ObjectCacheGetObjectFunc getobject_func;
     void *user_data;
@@ -262,26 +226,19 @@ private:
 
 typedef LLVMPYObjectCache *LLVMPYObjectCacheRef;
 
-
 API_EXPORT(LLVMPYObjectCacheRef)
 LLVMPY_CreateObjectCache(ObjectCacheNotifyFunc notify_func,
                          ObjectCacheGetObjectFunc getobject_func,
-                         void *user_data)
-{
+                         void *user_data) {
     return new LLVMPYObjectCache(notify_func, getobject_func, user_data);
 }
 
 API_EXPORT(void)
-LLVMPY_DisposeObjectCache(LLVMPYObjectCacheRef C)
-{
-    delete C;
-}
+LLVMPY_DisposeObjectCache(LLVMPYObjectCacheRef C) { delete C; }
 
 API_EXPORT(void)
-LLVMPY_SetObjectCache(LLVMExecutionEngineRef EE, LLVMPYObjectCacheRef C)
-{
+LLVMPY_SetObjectCache(LLVMExecutionEngineRef EE, LLVMPYObjectCacheRef C) {
     llvm::unwrap(EE)->setObjectCache(C);
 }
 
-
 } // end extern "C"
