@@ -13,6 +13,19 @@ _CMP_MAP = {
 }
 
 
+def _unop(opname, cls=instructions.Instruction):
+    def wrap(fn):
+        @functools.wraps(fn)
+        def wrapped(self, arg, name='', flags=()):
+            instr = cls(self.block, arg.type, opname, [arg], name, flags)
+            self._insert(instr)
+            return instr
+
+        return wrapped
+
+    return wrap
+
+
 def _binop(opname, cls=instructions.Instruction):
     def wrap(fn):
         @functools.wraps(fn)
@@ -541,6 +554,13 @@ class IRBuilder(object):
         """
         return self.sub(values.Constant(value.type, 0), value, name=name)
 
+    @_unop('fneg')
+    def fneg(self, arg, name='', flags=()):
+        """
+        Floating-point negative:
+            name = -arg
+        """
+
     #
     # Comparison APIs
     #
@@ -574,7 +594,7 @@ class IRBuilder(object):
         """
         return self._icmp('u', cmpop, lhs, rhs, name)
 
-    def fcmp_ordered(self, cmpop, lhs, rhs, name='', flags=[]):
+    def fcmp_ordered(self, cmpop, lhs, rhs, name='', flags=()):
         """
         Floating-point ordered comparison:
             name = lhs <cmpop> rhs
@@ -590,7 +610,7 @@ class IRBuilder(object):
         self._insert(instr)
         return instr
 
-    def fcmp_unordered(self, cmpop, lhs, rhs, name='', flags=[]):
+    def fcmp_unordered(self, cmpop, lhs, rhs, name='', flags=()):
         """
         Floating-point unordered comparison:
             name = lhs <cmpop> rhs
@@ -606,12 +626,13 @@ class IRBuilder(object):
         self._insert(instr)
         return instr
 
-    def select(self, cond, lhs, rhs, name=''):
+    def select(self, cond, lhs, rhs, name='', flags=()):
         """
         Ternary select operator:
             name = cond ? lhs : rhs
         """
-        instr = instructions.SelectInstr(self.block, cond, lhs, rhs, name=name)
+        instr = instructions.SelectInstr(self.block, cond, lhs, rhs, name=name,
+                                         flags=flags)
         self._insert(instr)
         return instr
 
@@ -852,14 +873,14 @@ class IRBuilder(object):
     # Call APIs
 
     def call(self, fn, args, name='', cconv=None, tail=False, fastmath=(),
-             attrs=()):
+             attrs=(), arg_attrs=None):
         """
         Call function *fn* with *args*:
             name = fn(args...)
         """
         inst = instructions.CallInstr(self.block, fn, args, name=name,
                                       cconv=cconv, tail=tail, fastmath=fastmath,
-                                      attrs=attrs)
+                                      attrs=attrs, arg_attrs=arg_attrs)
         self._insert(inst)
         return inst
 
@@ -888,9 +909,11 @@ class IRBuilder(object):
         return self.asm(ftype, "", "{%s}" % reg_name, [value], True, name)
 
     def invoke(self, fn, args, normal_to, unwind_to,
-               name='', cconv=None, tail=False):
+               name='', cconv=None, fastmath=(), attrs=(), arg_attrs=None):
         inst = instructions.InvokeInstr(self.block, fn, args, normal_to,
-                                        unwind_to, name=name, cconv=cconv)
+                                        unwind_to, name=name, cconv=cconv,
+                                        fastmath=fastmath, attrs=attrs,
+                                        arg_attrs=arg_attrs)
         self._set_terminator(inst)
         return inst
 
@@ -963,8 +986,8 @@ class IRBuilder(object):
 
     # PHI APIs
 
-    def phi(self, typ, name=''):
-        inst = instructions.PhiInstr(self.block, typ, name=name)
+    def phi(self, typ, name='', flags=()):
+        inst = instructions.PhiInstr(self.block, typ, name=name, flags=flags)
         self._insert(inst)
         return inst
 
